==> s-1.0.1.tgz: package/src/utils/aws/handlerTemplate.js <==
const httpResponse = (body, requestOrigin) => {
  let origin = '*'
  const config = require('./index').config || {}
  if (config.origins) {
    if (config.origins.includes(requestOrigin)) {
      origin = requestOrigin
    } else {
      origin = null
    }
  }
  return {
    statusCode: (body.error || !origin) ? 500 : 200,
    headers: {
      'X-Requested-With': '*',
      'Access-Control-Allow-Headers': '*',
      'Access-Control-Allow-Origin': origin,
      'Access-Control-Allow-Methods': '*'
    },
    body: JSON.stringify(body)
  }
}

const getAvailableFunctions = (library) => {
  const fns = []
  Object.keys(library).forEach(key => {
    if (typeof library[key] === 'function') {
      fns.push(key)
    }
  })
  return fns
}

module.exports.s = (e, ctx, cb) => {
  const requestOrigin = e.headers['Origin']
  delete require.cache[require.resolve('./index')]
  try {
    const library = require('./index.js')
    const availableFunctions = getAvailableFunctions(library)
    const functionName = e.headers['s-function']
    const args = JSON.parse(e.body)

    if (!functionName) {
      return cb(null, httpResponse(availableFunctions, requestOrigin))
    } else if (!availableFunctions.includes(functionName)) {
      return cb(null, httpResponse({error: `Function ${functionName} does not exist`}, requestOrigin))
    } else {
      console.log(`Function Called: ${functionName}`)
      const returnValue = library[functionName](args, ctx)
      return Promise.resolve(returnValue)
        .then((res) => cb(null, httpResponse(res, requestOrigin)))
        .catch((error) => {
          console.log(error.stack)
          cb(null, httpResponse({error: error.stack}, requestOrigin))
        })
    }
  } catch (error) {
    // note: I don't use cb(error) because lambda would ugly-log this automatically
    console.log(error.stack)
    cb(null, httpResponse({error: error.stack}, requestOrigin))
  }
}

==> s-1.0.4.tgz: package/src/utils/aws/handlerTemplate.js <==
const httpResponse = (body, requestOrigin) => {
  let origin = '*'
  const config = require('./index').config || {}
  if (config.origins) {
    if (config.origins.includes(requestOrigin)) {
      origin = requestOrigin
    } else {
      origin = null
    }
  }
  return {
    statusCode: (body.error || !origin) ? 500 : 200,
    headers: {
      'X-Requested-With': '*',
      'Access-Control-Allow-Headers': '*',
      'Access-Control-Allow-Origin': origin,
      'Access-Control-Allow-Methods': '*'
    },
    body: JSON.stringify(body)
  }
}

module.exports.s = (e, ctx, cb) => {
  const requestOrigin = e.headers['Origin']
  delete require.cache[require.resolve('./index')]
  try {
    const library = require('./index.js')
    const functionName = e.headers['s-function']
    const args = JSON.parse(e.body)

    if (!library[functionName]) {
      return cb(null, httpResponse({error: `Function ${functionName} does not exist in your serverless library`}, requestOrigin))
    } else {
      console.log(`Function Called: ${functionName}`)
      const returnValue = library[functionName](args, ctx)
      return Promise.resolve(returnValue)
        .then((res) => cb(null, httpResponse(res, requestOrigin)))
        .catch((error) => {
          console.log(error.stack)
          cb(null, httpResponse({error: error.stack}, requestOrigin))
        })
    }
  } catch (error) {
    // note: I don't use cb(error) because lambda would ugly-log this automatically
    console.log(error.stack)
    cb(null, httpResponse({error: error.stack}, requestOrigin))
  }
}
